@@ -1,15 +1,7 @@
 package DBIx::CheckConnectivity::Driver::mysql;
-
 use warnings;
 use strict;
-
-sub system_database {
-    return '';
-}
-
-sub not_exist_error {
-    return qr/unknown database/i;
-}
+use base qw/DBIx::CheckConnectivity::Driver/;
 
 1;
 
@@ -23,14 +15,6 @@ DBIx::CheckConnectivity::mysql -
 
 =over 4
 
-=item system_database
-
-return ''
-
-=item not_exist_error
-
-return qr/unknown database/i;
-
 =back
 
 =head1 AUTHOR
